@@ -54,8 +54,9 @@
 #include <readline/history.h>
 #endif /* HAVE_READLINE_HISTORY_H */
 
-// editline doesn't have this
+#ifdef HAVE_HISTORY_SET_HISTORY_STATE
 #define HAVE_HISTORY_STATE 1
+#endif /* HAVE_HISTORY_SET_HISTORY_STATE */
 
 #else /* USE_READLINE */
 
@@ -75,6 +76,11 @@
 #endif /* HAVE_EDIT_READLINE_READLINE_H */
 #endif /* HAVE_EDITLINE_READLINE_H */
 
+// At the time of this writing, editline doesn't have this.
+#ifdef HAVE_HISTORY_SET_HISTORY_STATE
+#define HAVE_HISTORY_STATE 1
+#endif /* HAVE_HISTORY_SET_HISTORY_STATE */
+
 #endif /* USE_READLINE */
 #endif /* HAVE_LIBREADLINE */
 
@@ -90,7 +96,7 @@ using namespace std;
 #define PURELIB "/usr/local/lib/pure-" PACKAGE_VERSION
 #endif
 
-#define COPYRIGHT "Copyright (c) 2008-2013 by Albert Graef"
+#define COPYRIGHT "Copyright (c) 2008-2014 by Albert Graef"
 #define USAGE \
 "Usage:            pure [options ...] [-x] script [args ...]\n\
                   pure [options ...] [-b|-c|-i] [script ...] [-- args ...]\n\
